==> mastapy-10.1.1b1-py3-none-any.whl: mastapy/bearings/_1513.py <==
﻿'''_1513.py

BearingSettings
'''


from mastapy._internal.implicit import enum_with_selected_value
from mastapy.bearings import (
    _1523, _1522, _1515, _1516
)
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy.bearings.bearing_results.rolling.skf_module import _1706
from mastapy.utility import _1139
from mastapy._internal.python_net import python_net_import

_BEARING_SETTINGS = python_net_import('SMT.MastaAPI.Bearings', 'BearingSettings')


__docformat__ = 'restructuredtext en'
__all__ = ('BearingSettings',)


class BearingSettings(_1139.PerMachineSettings):
    '''BearingSettings

    This is a mastapy class.
    '''

    TYPE = _BEARING_SETTINGS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BearingSettings.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def default_roller_profile(self) -> 'enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes':
        '''enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes: 'DefaultRollerProfile' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.DefaultRollerProfile, value) if self.wrapped.DefaultRollerProfile else None

    @default_roller_profile.setter
    def default_roller_profile(self, value: 'enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.DefaultRollerProfile = value

    @property
    def tolerance_used_for_diameter_warnings_and_database_filter(self) -> 'float':
        '''float: 'ToleranceUsedForDiameterWarningsAndDatabaseFilter' is the original name of this property.'''

        return self.wrapped.ToleranceUsedForDiameterWarningsAndDatabaseFilter

    @tolerance_used_for_diameter_warnings_and_database_filter.setter
    def tolerance_used_for_diameter_warnings_and_database_filter(self, value: 'float'):
        self.wrapped.ToleranceUsedForDiameterWarningsAndDatabaseFilter = float(value) if value else 0.0

    @property
    def failure_probability_for_rating_life(self) -> '_1522.RatingLife':
        '''RatingLife: 'FailureProbabilityForRatingLife' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.FailureProbabilityForRatingLife)
        return constructor.new(_1522.RatingLife)(value) if value else None

    @failure_probability_for_rating_life.setter
    def failure_probability_for_rating_life(self, value: '_1522.RatingLife'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.FailureProbabilityForRatingLife = value

    @property
    def use_plain_journal_bearing_misalignment_factors(self) -> 'bool':
        '''bool: 'UsePlainJournalBearingMisalignmentFactors' is the original name of this property.'''

        return self.wrapped.UsePlainJournalBearingMisalignmentFactors

    @use_plain_journal_bearing_misalignment_factors.setter
    def use_plain_journal_bearing_misalignment_factors(self, value: 'bool'):
        self.wrapped.UsePlainJournalBearingMisalignmentFactors = bool(value) if value else False

    @property
    def include_exponent_and_reduction_factors_in_isots162812008(self) -> '_1515.ExponentAndReductionFactorsInISO16281Calculation':
        '''ExponentAndReductionFactorsInISO16281Calculation: 'IncludeExponentAndReductionFactorsInISOTS162812008' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.IncludeExponentAndReductionFactorsInISOTS162812008)
        return constructor.new(_1515.ExponentAndReductionFactorsInISO16281Calculation)(value) if value else None

    @include_exponent_and_reduction_factors_in_isots162812008.setter
    def include_exponent_and_reduction_factors_in_isots162812008(self, value: '_1515.ExponentAndReductionFactorsInISO16281Calculation'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.IncludeExponentAndReductionFactorsInISOTS162812008 = value

    @property
    def lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings(self) -> 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions':
        '''enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions: 'LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings, value) if self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings else None

    @lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings.setter
    def lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings(self, value: 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings = value

    @property
    def lubricant_film_temperature_calculation_splashed_submerged_bearings(self) -> 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions':
        '''enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions: 'LubricantFilmTemperatureCalculationSplashedSubmergedBearings' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings, value) if self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings else None

    @lubricant_film_temperature_calculation_splashed_submerged_bearings.setter
    def lubricant_film_temperature_calculation_splashed_submerged_bearings(self, value: 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings = value

    @property
    def ball_bearing_weibull_reliability_slope(self) -> 'float':
        '''float: 'BallBearingWeibullReliabilitySlope' is the original name of this property.'''

        return self.wrapped.BallBearingWeibullReliabilitySlope

    @ball_bearing_weibull_reliability_slope.setter
    def ball_bearing_weibull_reliability_slope(self, value: 'float'):
        self.wrapped.BallBearingWeibullReliabilitySlope = float(value) if value else 0.0

    @property
    def roller_bearing_weibull_reliability_slope(self) -> 'float':
        '''float: 'RollerBearingWeibullReliabilitySlope' is the original name of this property.'''

        return self.wrapped.RollerBearingWeibullReliabilitySlope

    @roller_bearing_weibull_reliability_slope.setter
    def roller_bearing_weibull_reliability_slope(self, value: 'float'):
        self.wrapped.RollerBearingWeibullReliabilitySlope = float(value) if value else 0.0

    @property
    def third_weibull_parameter(self) -> 'float':
        '''float: 'ThirdWeibullParameter' is the original name of this property.'''

        return self.wrapped.ThirdWeibullParameter

    @third_weibull_parameter.setter
    def third_weibull_parameter(self, value: 'float'):
        self.wrapped.ThirdWeibullParameter = float(value) if value else 0.0

    @property
    def enable_skf_module(self) -> 'bool':
        '''bool: 'EnableSKFModule' is the original name of this property.'''

        return self.wrapped.EnableSKFModule

    @enable_skf_module.setter
    def enable_skf_module(self, value: 'bool'):
        self.wrapped.EnableSKFModule = bool(value) if value else False

    @property
    def log_http_requests(self) -> 'bool':
        '''bool: 'LogHTTPRequests' is the original name of this property.'''

        return self.wrapped.LogHTTPRequests

    @log_http_requests.setter
    def log_http_requests(self, value: 'bool'):
        self.wrapped.LogHTTPRequests = bool(value) if value else False

    @property
    def log_file_path(self) -> 'str':
        '''str: 'LogFilePath' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LogFilePath

    @property
    def skf_credentials(self) -> '_1706.SKFCredentials':
        '''SKFCredentials: 'SKFCredentials' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1706.SKFCredentials)(self.wrapped.SKFCredentials) if self.wrapped.SKFCredentials else None

==> mastapy-10.1.2-py3-none-any.whl: mastapy/bearings/_1513.py <==
﻿'''_1513.py

BearingSettings
'''


from mastapy._internal.implicit import enum_with_selected_value
from mastapy.bearings import (
    _1523, _1522, _1515, _1516
)
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy.bearings.bearing_results.rolling.skf_module import _1706
from mastapy.utility import _1139
from mastapy._internal.python_net import python_net_import

_BEARING_SETTINGS = python_net_import('SMT.MastaAPI.Bearings', 'BearingSettings')


__docformat__ = 'restructuredtext en'
__all__ = ('BearingSettings',)


class BearingSettings(_1139.PerMachineSettings):
    '''BearingSettings

    This is a mastapy class.
    '''

    TYPE = _BEARING_SETTINGS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BearingSettings.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def default_roller_profile(self) -> 'enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes':
        '''enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes: 'DefaultRollerProfile' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.DefaultRollerProfile, value) if self.wrapped.DefaultRollerProfile else None

    @default_roller_profile.setter
    def default_roller_profile(self, value: 'enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.DefaultRollerProfile = value

    @property
    def tolerance_used_for_diameter_warnings_and_database_filter(self) -> 'float':
        '''float: 'ToleranceUsedForDiameterWarningsAndDatabaseFilter' is the original name of this property.'''

        return self.wrapped.ToleranceUsedForDiameterWarningsAndDatabaseFilter

    @tolerance_used_for_diameter_warnings_and_database_filter.setter
    def tolerance_used_for_diameter_warnings_and_database_filter(self, value: 'float'):
        self.wrapped.ToleranceUsedForDiameterWarningsAndDatabaseFilter = float(value) if value else 0.0

    @property
    def failure_probability_for_rating_life(self) -> '_1522.RatingLife':
        '''RatingLife: 'FailureProbabilityForRatingLife' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.FailureProbabilityForRatingLife)
        return constructor.new(_1522.RatingLife)(value) if value else None

    @failure_probability_for_rating_life.setter
    def failure_probability_for_rating_life(self, value: '_1522.RatingLife'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.FailureProbabilityForRatingLife = value

    @property
    def use_plain_journal_bearing_misalignment_factors(self) -> 'bool':
        '''bool: 'UsePlainJournalBearingMisalignmentFactors' is the original name of this property.'''

        return self.wrapped.UsePlainJournalBearingMisalignmentFactors

    @use_plain_journal_bearing_misalignment_factors.setter
    def use_plain_journal_bearing_misalignment_factors(self, value: 'bool'):
        self.wrapped.UsePlainJournalBearingMisalignmentFactors = bool(value) if value else False

    @property
    def include_exponent_and_reduction_factors_in_isots162812008(self) -> '_1515.ExponentAndReductionFactorsInISO16281Calculation':
        '''ExponentAndReductionFactorsInISO16281Calculation: 'IncludeExponentAndReductionFactorsInISOTS162812008' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.IncludeExponentAndReductionFactorsInISOTS162812008)
        return constructor.new(_1515.ExponentAndReductionFactorsInISO16281Calculation)(value) if value else None

    @include_exponent_and_reduction_factors_in_isots162812008.setter
    def include_exponent_and_reduction_factors_in_isots162812008(self, value: '_1515.ExponentAndReductionFactorsInISO16281Calculation'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.IncludeExponentAndReductionFactorsInISOTS162812008 = value

    @property
    def lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings(self) -> 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions':
        '''enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions: 'LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings, value) if self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings else None

    @lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings.setter
    def lubricant_film_temperature_calculation_pressure_fed_grease_filled_bearings(self, value: 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LubricantFilmTemperatureCalculationPressureFedGreaseFilledBearings = value

    @property
    def lubricant_film_temperature_calculation_splashed_submerged_bearings(self) -> 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions':
        '''enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions: 'LubricantFilmTemperatureCalculationSplashedSubmergedBearings' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings, value) if self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings else None

    @lubricant_film_temperature_calculation_splashed_submerged_bearings.setter
    def lubricant_film_temperature_calculation_splashed_submerged_bearings(self, value: 'enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_FluidFilmTemperatureOptions.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LubricantFilmTemperatureCalculationSplashedSubmergedBearings = value

    @property
    def ball_bearing_weibull_reliability_slope(self) -> 'float':
        '''float: 'BallBearingWeibullReliabilitySlope' is the original name of this property.'''

        return self.wrapped.BallBearingWeibullReliabilitySlope

    @ball_bearing_weibull_reliability_slope.setter
    def ball_bearing_weibull_reliability_slope(self, value: 'float'):
        self.wrapped.BallBearingWeibullReliabilitySlope = float(value) if value else 0.0

    @property
    def roller_bearing_weibull_reliability_slope(self) -> 'float':
        '''float: 'RollerBearingWeibullReliabilitySlope' is the original name of this property.'''

        return self.wrapped.RollerBearingWeibullReliabilitySlope

    @roller_bearing_weibull_reliability_slope.setter
    def roller_bearing_weibull_reliability_slope(self, value: 'float'):
        self.wrapped.RollerBearingWeibullReliabilitySlope = float(value) if value else 0.0

    @property
    def third_weibull_parameter(self) -> 'float':
        '''float: 'ThirdWeibullParameter' is the original name of this property.'''

        return self.wrapped.ThirdWeibullParameter

    @third_weibull_parameter.setter
    def third_weibull_parameter(self, value: 'float'):
        self.wrapped.ThirdWeibullParameter = float(value) if value else 0.0

    @property
    def enable_skf_module(self) -> 'bool':
        '''bool: 'EnableSKFModule' is the original name of this property.'''

        return self.wrapped.EnableSKFModule

    @enable_skf_module.setter
    def enable_skf_module(self, value: 'bool'):
        self.wrapped.EnableSKFModule = bool(value) if value else False

    @property
    def log_http_requests(self) -> 'bool':
        '''bool: 'LogHTTPRequests' is the original name of this property.'''

        return self.wrapped.LogHTTPRequests

    @log_http_requests.setter
    def log_http_requests(self, value: 'bool'):
        self.wrapped.LogHTTPRequests = bool(value) if value else False

    @property
    def log_file_path(self) -> 'str':
        '''str: 'LogFilePath' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LogFilePath

    @property
    def skf_credentials(self) -> '_1706.SKFCredentials':
        '''SKFCredentials: 'SKFCredentials' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1706.SKFCredentials)(self.wrapped.SKFCredentials) if self.wrapped.SKFCredentials else None
